@@ -1,4 +1,6 @@
-/* $Id: tools.h 1090 2010-04-15 16:03:53Z glx $ */
+/* $Id: tools.h 2238 2011-08-02 15:16:14Z truebrain $ */
+
+/** @file src/tools.h Various definitions. */
 
 #ifndef TOOLS_H
 #define TOOLS_H
@@ -15,6 +17,7 @@ typedef enum IndexType {
 
 struct Unit;
 struct Structure;
+struct Object;
 
 extern uint16 Tools_AdjustToGameSpeed(uint16 normal, uint16 minimum, uint16 maximum, bool inverseSpeed);
 extern IndexType Tools_Index_GetType(uint16 encoded);
@@ -25,27 +28,14 @@ extern uint16 Tools_Index_GetPackedTile(uint16 encoded);
 extern tile32 Tools_Index_GetTile(uint16 encoded);
 extern struct Unit *Tools_Index_GetUnit(uint16 encoded);
 extern struct Structure *Tools_Index_GetStructure(uint16 encoded);
-extern csip32 Tools_GetSmallestIP(csip32 csip);
-extern void Tools_Memmove(csip32 src, csip32 dst, uint32 count);
+extern struct Object *Tools_Index_GetObject(uint16 encoded);
+
 extern uint8 Tools_Random_256();
+extern void Tools_Random_Seed(uint32 seed);
 extern uint16 Tools_RandomRange(uint16 min, uint16 max);
 
-
-extern void emu_Tools_Shld();
-extern void emu_Tools_Shrd();
-extern void emu_Tools_Index_GetType();
-extern void emu_Tools_Index_Decode();
-extern void emu_Tools_Index_Encode();
-extern void emu_Tools_Index_IsValid();
-extern void emu_Tools_Index_GetPackedTile();
-extern void emu_Tools_Index_GetTile();
-extern void emu_Tools_Index_GetUnit();
-extern void emu_Tools_Index_GetStructure();
-extern void emu_Tools_GetSmallestIP();
-extern void emu_Tools_GetSmallestIP2();
-extern void emu_Tools_Memmove();
-extern void emu_Tools_Random_256();
-extern void emu_Tools_RandomRange();
-extern void emu_Tools_PrintString();
+extern bool BitArray_Test(uint8 *array, uint16 index);
+extern void BitArray_Set(uint8 *array, uint16 index);
+extern void BitArray_Clear(uint8 *array, uint16 index);
 
 #endif /* TOOLS_H */
